==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/ui/base/builder/IContainerBuilder.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2015 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

/**
 * @file ui/base/builder/IContainerBuilder.cpp
 * @brief This file defines the implementation of the interface class  for the menubar builder.
 */

#include "ui/base/builder/IContainerBuilder.hpp"

namespace sight::ui::base
{

namespace builder
{

const IContainerBuilder::RegistryKeyType IContainerBuilder::REGISTRY_KEY = "::ui::base::ContainerBuilder";

//-----------------------------------------------------------------------------

IContainerBuilder::IContainerBuilder()
{
}

//-----------------------------------------------------------------------------

IContainerBuilder::~IContainerBuilder()
{
}

//-----------------------------------------------------------------------------

void IContainerBuilder::initialize(core::runtime::ConfigurationElement::sptr configuration)
{
}

//-----------------------------------------------------------------------------

ui::base::container::fwContainer::sptr IContainerBuilder::getContainer()
{
    return this->m_container;
}

//-----------------------------------------------------------------------------

} // namespace builder

} // namespace sight::ui::base

==> sight_21.1.1.orig.tar.gz: sight-21.1.1/libs/ui/base/builder/IContainerBuilder.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2015 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

/**
 * @file ui/base/builder/IContainerBuilder.cpp
 * @brief This file defines the implementation of the interface class  for the menubar builder.
 */

#include "ui/base/builder/IContainerBuilder.hpp"

namespace sight::ui::base
{

namespace builder
{

const IContainerBuilder::RegistryKeyType IContainerBuilder::REGISTRY_KEY = "::ui::base::ContainerBuilder";

//-----------------------------------------------------------------------------

IContainerBuilder::IContainerBuilder()
{
}

//-----------------------------------------------------------------------------

IContainerBuilder::~IContainerBuilder()
{
}

//-----------------------------------------------------------------------------

void IContainerBuilder::initialize(core::runtime::ConfigurationElement::sptr)
{
}

//-----------------------------------------------------------------------------

ui::base::container::fwContainer::sptr IContainerBuilder::getContainer()
{
    return this->m_container;
}

//-----------------------------------------------------------------------------

} // namespace builder

} // namespace sight::ui::base
